@@ -113,12 +113,6 @@ static const OptionInfoRec KeyboardOptions[] = {
     { -1,			NULL,		  OPTV_NONE,	{0}, FALSE }
 };
 
-/* Xorg 1.6 and earlier put the default XKB rules file in __XKBDEFRULES__
-   in xorg-server.h, later versions switched to XKB_DFLT_RULES */
-#if !defined(XKB_DFLT_RULES) && defined(__XKBDEFRULES__)
-# define XKB_DFLT_RULES __XKBDEFRULES__
-#endif
-
 static const char *kbdDefaults[] = {
 #ifdef XQUEUE 
     "Protocol",		"Xqueue",
@@ -126,7 +120,7 @@ static const char *kbdDefaults[] = {
     "Protocol",		"standard",
 #endif
     "AutoRepeat",	"500 30",
-    "XkbRules",		XKB_DFLT_RULES,
+    "XkbRules",		"base",
     "XkbModel",		"pc105",
     "XkbLayout",	"us",
     "CustomKeycodes",	"off",
@@ -313,7 +307,6 @@ KbdCtrl( DeviceIntPtr device, KeybdCtrl *ctrl)
    leds = ctrl->leds & ~(XCAPS | XNUM | XSCR); /* ??? */
    pKbd->leds = leds;
   pKbd->SetLeds(pInfo, pKbd->leds);
-  pKbd->autoRepeat = ctrl->autoRepeat;
 }
 
 static void
